### What is Oracle Free Tier?

When exploring cloud services, one of the most important factors to consider is how much you can accomplish without breaking the bank. 

That's where **Oracle's Free Tier** comes in—a cloud offering that provides access to powerful computing, storage, networking, and database resources at no cost. 

Oracle’s Free Tier gives you the freedom to build and scale applications without worrying about upfront costs or limitations. 

In this post, we’ll dive into what Oracle Free Tier is, what it offers, and how you can take advantage of it. 

### Access Oracle's free services today:  https://www.oracle.com/cloud/free/



## Before we begin...
# What is a VPS (Virtual Private Server)?
<!-- lead -->
Why Oracle Cloud is still one of the best offerings on the planet since its launch.

A **Virtual Private Server (VPS)** is a type of server that operates in a shared environment but behaves as though it's a dedicated server. The VPS provider allocates a portion of their physical server's resources to you, along with an operating system, granting you the freedom to build websites, run software, or even host game servers.

With a VPS, you essentially have your own **virtual machine** on the server, allowing you complete control over your space. This flexibility makes VPS hosting ideal when you require more power than a shared hosting account but don't want the hefty costs associated with a dedicated server. It combines the functionality and customization of a dedicated server at a fraction of the price.

Unlike shared hosting, where hundreds of websites are housed on the same server, VPS hosting offers much greater control over your resources. You can install custom software, configure settings, and tailor the environment to your specific needs. Best of all, VPS hosting is often far less expensive than dedicated hosting, making it a great choice for those seeking the best of both worlds.

## Why Do You Need a VPS?

VPS hosting offers enhanced security and privacy for individual websites and applications. 

It’s a fantastic option for hosting websites, online stores, or any other project that demands ample resources and scalability. VPS hosting is like a **server on steroids**, providing abundant resources and the ability to scale up or down as your needs evolve. It’s an excellent choice for both beginners and experienced users alike.

With a VPS, you’ll experience a significant speed boost for your website—much faster than shared hosting can offer. If you're running a **mission-critical** website or project that requires zero downtime or experiences significant traffic fluctuations, a VPS is a must.

Additionally, virtual private servers tend to be as affordable as quality shared hosting plans but come with far less downtime. 

Besides web hosting, VPS is a perfect solution for hosting game servers. Whether you’re running a **Minecraft** server or another game, you can easily set up a VPS and play with your friends.

When your shared hosting account reaches its limits, it's time to upgrade to a VPS to harness the full power of virtual servers.

A VPS hosting environment allows you to host websites without sharing resources with others on the same server, giving you complete control over your environment. You can also host multiple websites on a single physical server, lowering costs and improving performance. 

For high-traffic websites, VPS hosting is the way to go—it delivers superior performance and reliability compared to shared hosting.

### Free Trial Explained

Oracle Cloud offers a **free trial** for first-time customers, providing an excellent opportunity to explore the platform and test its capabilities before making a financial commitment. This trial allows users to familiarize themselves with Oracle’s services, ensuring compatibility and performance within their specific use cases.

The free trial is a hands-on way for users to gain valuable experience and understand how to best utilize the platform’s features. It helps potential customers feel more confident and secure about how Oracle Cloud will perform in their environment, making it an ideal way to experiment with different cloud solutions.

The trial lasts for **30 days** and includes **$300 in credits**, giving users full access to Oracle Cloud's upgraded services during this period. These credits can be used across a wide range of services, including databases, analytics, compute, and container engines for Kubernetes. 

It's important to note that the **free trial** is different from the **Always Free Tier**. Once the trial ends, users transition into the Always Free Tier, which provides a set of free resources that last indefinitely. The trial’s credits are consumed at a discounted rate, allowing users to fully explore Oracle Cloud’s premium offerings before the free tier kicks in. 

This trial is available worldwide in multiple regions, but remember to distinguish between the **trial** and the **Always Free Tier**, as they serve different purposes and offer different benefits.

#### Now that we know what those concepts are, lets talk about free hosting.
## Oracle Always Free Tier: Features

Oracle offers an exceptionally generous **Always Free Tier** that provides multiple services at no cost. 

Below is a summarized breakdown of what Oracle offers within the **Always Free** plan:

### **Compute**
- **AMD Compute Instance**  
  2 AMD-based Compute VMs with 1/8 OCPU and 1 GB of memory each.
- **Arm Compute Instance**  
  4 Arm-based Ampere A1 cores with 24 GB of memory, which can be used as a single VM or split into up to 4 VMs.
- **3,000 OCPU hours** and **18,000 GB hours** per month.

### **Developer Services**
- **APEX (Application Express)**  
  A low-code platform for building, integrating, and innovating applications with up to 744 hours per instance.

### **Networking**
- **Flexible Network Load Balancer**  
  Provides automated traffic distribution, ensuring services remain available by routing traffic only to healthy servers.  
  Always Free: 1 instance.
- **Load Balancer**  
  Allows for highly available load balancers within your Virtual Cloud Network (VCN) with 10 Mbps bandwidth.  
  Always Free: 1 instance.
- **Outbound Data Transfer**  
  Always Free: Up to 10 TB per month.
- **Service Connector Hub**  
  A cloud message bus platform for moving data between Oracle Cloud services.  
  Always Free: 2 service connectors.
- **Site-to-Site VPN**  
  Secure IPSec connection between your on-premises network and your VCN.  
  Always Free: 50 IPSec connections.
- **VCN Flow Logs**  
  Logs traffic through your VCN for auditing and security purposes.  
  Always Free: 10 GB per month shared across OCI Logging services.
- **Virtual Cloud Networks (VCN)**  
  Allows the creation of software-defined networks.  
  Always Free: 2 VCNs with IPv4 and IPv6 support.

### **Observability and Management**
- **Application Performance Monitoring**  
  Monitors application performance and diagnoses issues.  
  Always Free: Up to 1000 tracing events and 10 Synthetic Monitoring runs per hour.
- **Email Delivery**  
  Managed solution for sending secure, high-volume emails.  
  Always Free: Up to 100 emails sent per day.
- **Logging**  
  Centralized, scalable logging service.  
  Always Free: Up to 10 GB per month.
- **Monitoring**  
  Queries metrics and manages alarms to monitor the health of cloud resources.  
  Always Free: Up to 500 million ingestion datapoints, 1 billion retrieval datapoints.
- **Notification**  
  Sends alerts based on cloud resource activities.  
  Always Free: Up to 1 million HTTP notifications and 1,000 email notifications per month.

### **Oracle Databases**
- **Autonomous Database**  
  Fully managed databases like Oracle Autonomous Transaction Processing and Autonomous Data Warehouse.  
  Always Free: Up to two databases total.
- **HeatWave**  
  An integrated service for transactions, analytics, and generative AI.  
  Always Free: 1 standalone instance with 50 GB of storage and 50 GB of backup storage.
- **NoSQL Database**  
  Fully managed, low-latency NoSQL database.  
  Always Free: Up to 133 million reads, 133 million writes per month, and 25 GB of storage per table (up to 3 tables).

### **Others**
- **Console Dashboards**  
  Custom dashboards to monitor resources and key metrics.  
  Always Free: Up to 100 dashboards.

### **Security**
- **Bastions**  
  Provides restricted SSH access to resources without public endpoints.  
  Always Free: Up to 5 OCI Bastions.
- **Certificates**  
  Issuance, storage, and management of certificates, including automatic renewal.  
  Always Free: Up to 5 Private CAs and 150 private TLS certificates.
- **Vault**  
  Manages master encryption keys and secrets with hardware security module (HSM) protection.  
  Always Free: Up to 20 key versions and 150 secrets.

### **Storage**
- **Archive Storage**  
  Unstructured archive storage.  
  Always Free: Up to 20 GB total for standard, infrequent, and archive storage.
- **Block Volume Storage**  
  Boot and block volume storage.  
  Always Free: Up to 2 block volumes (200 GB total) and 5 backups.
- **Object Storage**  
  Object Storage API requests.  
  Always Free: Up to 50,000 API requests per month.
- **Object Storage - Infrequent Access**  
  Unstructured storage for infrequently accessed data.  
  Always Free: Up to 20 GB total.
- **Object Storage - Standard**  
  Standard unstructured storage.  
  Always Free: Up to 20 GB total for standard, infrequent, and archive storage.

## Oracle Free Tier: A Comprehensive Breakdown of the Above summary

Oracle Cloud’s Always Free Tier stands out as a top choice for developers, startups, and businesses that require a robust, scalable cloud environment without the burden of upfront costs. With an impressive suite of compute, storage, database, and networking services, Oracle consistently outperforms competitors, offering far more generous free resources that can support everything from small web applications to more demanding, high-traffic environments.

In my personal experience, I’ve hosted Discord-Linux.com on Oracle Cloud for over 5 years, and I can confidently say that I have had zero issues during this time. The platform has proven to be reliable and efficient, handling everything from server management to traffic fluctuations effortlessly. In fact, the very blog you are reading is running on Oracle Cloud, utilizing only the free resources available under the Always Free Tier. Oracle’s stability and generous offering make it an unbeatable solution for those looking for both reliability and scalability without the associated costs.

Below, we’ll review Oracle’s **Always Free Tier** offerings, highlight the strengths and limitations, and assess how they compare to other providers like AWS, Google Cloud, and Microsoft Azure.

### **Compute Services**

Oracle Cloud’s **compute offerings** are perhaps the most significant draw of the Always Free Tier. The **AMD Compute Instances** and **Arm Compute Instances** provide considerable flexibility for users with a variety of needs.

- **AMD Compute Instance**: This includes **2 VMs** with 1/8 OCPU and 1 GB of memory each. While these may seem modest specs, for simple workloads such as small web servers, test environments, or lightweight applications, these VMs can be invaluable. The ability to run two instances simultaneously increases the scope of potential projects, making it possible to deploy a frontend/backend setup or even experiment with multi-node applications.

- **Arm Compute Instance**: The **Arm-based Ampere A1** cores are the stars of Oracle’s free compute resources. You get **24 GB of memory**, which can be allocated to **one large VM or split into four smaller VMs**. This flexibility offers developers an excellent opportunity to scale their applications, test distributed systems, or handle larger workloads without paying a cent. The performance of Ampere A1 processors is highly competitive, and with up to **3,000 OCPU hours** per month, users can push these instances to handle significant loads, making them suitable for high-traffic websites, data processing tasks, or even hosting games like Minecraft.

Oracle’s free compute offerings stand out for providing more CPU hours than competitors, allowing for sustained, non-stop operations, unlike other platforms that offer more limited timeframes.

### **Developer Services**

- **APEX (Application Express)**: Oracle APEX is one of the industry’s leading **low-code platforms**, and Oracle’s inclusion of this in the Always Free Tier is a major boon for developers looking to quickly build and deploy applications. This service is ideal for businesses or individuals looking to create **internal tools**, web apps, or even mobile backends without needing to manage large infrastructure. With **up to 744 hours** per instance, it’s a valuable tool for anyone needing rapid development without the complexity of traditional coding.

### **Networking Features**

Networking is often where hidden costs accumulate in cloud platforms, but Oracle’s Always Free Tier offers a range of useful services that help alleviate these concerns.

- **Flexible Network Load Balancer**: Oracle’s **Network Load Balancer** ensures that your applications remain available, distributing traffic only to healthy servers. This is especially valuable for high-availability applications. While **1 instance** is available for free, it’s sufficient for most small-scale projects that require automated traffic distribution.

- **Load Balancer**: For those who need a more traditional load balancing setup with **provisioned bandwidth** of up to 10 Mbps, this service provides excellent reliability. Again, **1 instance** is included, which can support basic scaling needs for your applications without additional cost.

- **Outbound Data Transfer**: A key feature here is the **10 TB per month** of free outbound data transfer. This is **exceptionally generous**, especially when compared to AWS or Google Cloud, which often charge after a very limited amount of free outbound data. This amount allows you to handle moderate to high-traffic websites, content delivery, or other data-heavy applications without worrying about expensive data transfer fees.

- **Site-to-Site VPN**: For hybrid cloud setups or secure on-premises connections, Oracle’s free tier includes **50 IPSec VPN connections**. This feature is invaluable for enterprises or developers needing to securely extend their local network into the cloud.

- **VCN Flow Logs**: Oracle offers **up to 10 GB of VCN flow logs per month**. These logs are essential for auditing traffic, troubleshooting network issues, and ensuring security across your cloud infrastructure.

### **Observability and Management**

- **Application Performance Monitoring (APM)**: Application monitoring and tracing are typically expensive features in most cloud platforms, but Oracle includes **1000 tracing events** and **10 Synthetic Monitoring runs per hour**. This is particularly useful for developers needing to pinpoint performance bottlenecks or ensure their applications are running smoothly without extra cost.

- **Email Delivery**: Oracle’s free tier allows you to send **up to 100 emails per day**, making it a viable solution for sending transactional emails, marketing campaigns, or notifications directly from your cloud applications.

- **Logging**: The **Logging service** allows for **up to 10 GB per month** of log data. This amount is sufficient for most small- to medium-scale applications and provides a scalable way to store and analyze logs without paying for third-party logging solutions.

- **Monitoring and Notifications**: Oracle offers **500 million ingestion datapoints** and **1 billion retrieval datapoints**, which is ample for even larger-scale applications. The **Notifications service** adds another layer of observability, sending up to **1 million HTTP notifications** or **1,000 emails per month**. These capabilities are highly advantageous for DevOps teams or developers needing to monitor performance metrics in real-time.

### **Oracle Databases**

Oracle is well-known for its database technology, and the Always Free Tier includes multiple offerings that can be pivotal for building robust data-driven applications.

- **Autonomous Databases**: Oracle’s Autonomous Database products, such as **Autonomous Transaction Processing** and **Autonomous Data Warehouse**, offer up to **two databases** free of charge. These databases are ideal for organizations requiring high performance, automation, and scalability without the management overhead of traditional database administration.

- **HeatWave**: With **1 standalone HeatWave instance** available, Oracle allows users to perform **AI-enhanced analytics** and data processing without needing to integrate external services. HeatWave’s ability to handle transactional workloads and lakehouse-scale analytics makes it a unique offering among cloud providers.

- **NoSQL Database**: For those working with **key-value**, document-based, or fixed-schema data, Oracle’s NoSQL offering provides **133 million reads/writes per month** with **25 GB of storage per table**. This is a compelling choice for building scalable, low-latency applications without worrying about high database costs.

### **Security Features**

- **Bastions**: Securely managing cloud infrastructure can be complex, but Oracle simplifies this with **up to 5 Bastions**. These provide **restricted SSH access** to resources without exposing them to the internet, ensuring enhanced security.

- **Certificates**: Oracle’s **Certificates service** allows for **automatic renewal** of up to **150 private TLS certificates**, along with **5 Private CAs**. This makes it easy for developers to manage secure communication between applications.

- **Vault**: OCI Vault is included with **20 key versions** and **150 secrets**. This provides a managed, secure way to handle encryption keys and secrets, which is essential for any sensitive or mission-critical application.

### **Storage Services**

Oracle’s storage options are well-rounded and comprehensive:

- **Block Volume Storage**: Up to **2 block volumes** with **200 GB total** storage, along with **5 backups**, make Oracle’s block storage a solid choice for hosting applications, databases, or even Docker containers.

- **Object Storage**: With **50,000 API requests per month** and **20 GB of standard and infrequent storage**, Oracle ensures that you have enough capacity for most personal or small-business use cases.

- **Archive Storage**: With **20 GB** of archive storage included, Oracle offers an easy solution for long-term backups or low-cost storage of infrequently accessed data.

### My Thoughts: Oracle Cloud's Always Free Tier

Oracle Cloud’s **Always Free Tier** stands out as a top choice for developers, startups, and businesses that require a robust, scalable cloud environment without the burden of upfront costs. With an impressive suite of compute, storage, database, and networking services, Oracle consistently outperforms competitors, offering far more generous free resources that can support everything from small web applications to more demanding, high-traffic environments.

Whether you're building a simple website, running a data-heavy application, or deploying complex services, Oracle Cloud provides the performance and flexibility needed to grow without incurring significant costs. Here’s a more in-depth look at its advantages and potential drawbacks:

### **Pros**:
- **Generous compute resources**: Oracle's Always Free Tier offers **Arm-based Ampere A1 cores** and **AMD-based VMs**, giving users access to up to **24 GB of memory**. These resources far exceed what other cloud providers offer for free, enabling you to run substantial workloads, such as high-traffic web servers, data processing, or even game hosting.
  
- **Substantial outbound data transfer**: Oracle provides **10 TB per month** of outbound data transfer, which is especially generous compared to AWS, Google Cloud, and Azure. This is more than enough to handle the data requirements of most websites, applications, or content delivery networks without worrying about hidden fees.

- **Industry-leading Autonomous and NoSQL Databases**: Free access to Oracle’s **Autonomous Database** and **NoSQL Database** ensures that users benefit from top-tier database management without the need for manual optimization or costly administration. This is a major selling point for developers who need powerful, scalable, and self-managing databases.

- **Extensive networking and security features**: Oracle includes **VPN**, **Site-to-Site VPN**, **Bastions**, and **Load Balancers**, all within the Always Free Tier. These networking and security tools are essential for securely connecting on-premise networks to the cloud and ensuring seamless service availability with minimal latency.

- **Comprehensive monitoring, logging, and notifications**: Oracle's observability services, including **Application Performance Monitoring**, **Logging**, **Monitoring**, and **Notifications**, provide deep insights into cloud applications. These tools offer real-time visibility into application health, performance metrics, and security, making it easy to maintain optimal operation without added cost.

### **Cons**:
- **Complex interface and setup**: While Oracle Cloud is highly powerful, its interface and setup process can be more complex than other platforms, such as AWS or Google Cloud, which offer more beginner-friendly user experiences. For those unfamiliar with Oracle’s cloud ecosystem, the learning curve can be steep, requiring additional time and effort to master.

- **Limited third-party integrations**: Oracle's ecosystem may not offer as wide a selection of third-party integrations and tools as AWS or Google Cloud. If your project relies heavily on third-party services, you might find Oracle's range somewhat restrictive compared to the broad support offered by its competitors.

# **FAQs**

- **Can I use a Virtual Credit Card (VCC) with Oracle Cloud?**  
  Unfortunately, Oracle Cloud does not support Virtual Credit Cards (VCC). 
  
  To complete the sign-up process, you’ll need to use a real credit card issued by a recognized bank. 
  
  This ensures verification and is necessary to activate your Oracle Cloud account, even for the free tier. 

- **Will I ever be charged using a free teir account?**  
  From what I have noticed Oracle does not seem to store payment details during the signup process within the always free service. 
  
  You must click the purple upgrade button and submit payment details aswell as wait 24 hours for your account to be upgraded to a paid version of the Oracle Cloud. 
  
  Due to this, there should not be any charges imposed during the usage of an always free account. 

- **Why was my Oracle VM made inaccessible even though I'm on the free tier?**  
  If your Oracle VM was created during the free trial period, it will be automatically locked after 30 days unless you upgrade to a paid account. 
  
  After the trial ends, you'll transition into the Always Free Tier, where any resources created under this tier will remain active indefinitely.

  To retain the data from your current instance, you can terminate the premium instance created during the trial without deleting the boot disk. 
  
  You can then use that boot disk to create a new Always Free instance. Once booted, your server will resume as expected, with all your software and configurations intact.

- **Can I mine cryptocurrency on my Oracle Cloud account?**  
  No, Oracle strictly prohibits cryptocurrency mining on its cloud infrastructure. 
  
  Any account found engaging in crypto mining will be terminated immediately. 
  
  Oracle enforces this policy to prevent resource abuse and ensure fair use of its free tier services.

- **Why are all ports blocked on my Oracle VPS?**  
  By default, all incoming traffic is blocked to enhance security. 
  
  To allow specific traffic, you’ll need to create **ingress rules** in your security group settings to open the required ports. 
  
  This ensures that only authorized traffic can access your virtual private server, offering an additional layer of protection.

- **Is Windows VPS available in the free tier?**  
  No, Windows VPS instances are not available in the Always Free Tier. 
  
  Access to Windows servers is reserved for upgraded accounts. 
  
  However, you can utilize Linux-based VMs, such as Ubuntu or Oracle Linux, in the free tier.

- **I received an "Out of Capacity" error. What should I do?**  
  Oracle Cloud resources are limited by region, and if your selected region has reached capacity, you’ll receive this error. 
  
  To resolve this, you can either wait for Oracle to replenish resources in your chosen region or select another region with available capacity to create your instance.

  I also find that upgrading your account is a great option to resolve this issue. Always free resources remain even if the account is upgraded. 